==> migrate_wizard-2.0.8-alpha1.tar.gz: migrate_wizard/src/Form/BaseFormFields.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */


namespace Drupal\migrate_wizard\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\migrate_wizard\MWConfigBuilder;
use Drupal\migrate_wizard\MWManageDataService;
use Drupal\migrate_wizard\MWManageFormService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * @property array|mixed|null currentConfig
 * @property string[] checkboxes
 * @property mixed|string destinyType
 * @property MWManageFormService manageFormService
 * @property array fieldsOriginBundle
 * @property MWManageDataService mwManageDataService
 * @property  array arrayFieldsOriginBundle
 * @property  array entityFieldsDestiny*
 * @property array[]|mixed $langCodes
 * @property $i18nMode
 */
abstract class BaseFormFields extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected $mwManageDataService;

  /**
   * {@inheritdoc}
   */
  protected $mwConfigBuilder;

  /**
   * {@inheritdoc}
   */
  protected $fieldsOriginBundle;

  /**
   * {@inheritdoc}
   */
  protected $arrayFieldsOriginBundle;

  /**
   * {@inheritdoc}
   */
  protected $config;

  /**
   * {@inheritdoc}
   */
  protected $entityFieldManager;

  /**
   * {@inheritdoc}
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  protected $entityFieldsDestiny;
  /**
   * {@inheritdoc}
   */
  protected $destinyType;
  protected $originType;
  protected $currentConfig;
  protected $originBundle;
  protected $manageFormService;
  protected $checkboxes = [
    'build_migration_config' => 'Build migration config',
  ];
  protected $langCodes = [
    'default_lang' => ['markup' => 'Default translation', 'value' => ''],
  ];

  protected $i18nMode;

  /**
   * Constructs a \Drupal\system\ConfigFormBase object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Config\TypedConfigManagerInterface|null $typedConfigManager
   *   The typed config manager.
   */
  public function __construct(ConfigFactoryInterface $config_factory,
                              MWManageDataService $mw_manage_data_service,
                              MWConfigBuilder $mw_config_builder,
                              EntityFieldManagerInterface $entity_field_manager,
                              EntityTypeManagerInterface $entity_type_manager,
                              MWManageFormService $manage_form_service,
                              protected $typedConfigManager = NULL) {
    parent::__construct($config_factory, $typedConfigManager);
    $this->mwManageDataService = $mw_manage_data_service;
    $this->mwConfigBuilder = $mw_config_builder;
    $this->config = $config_factory->getEditable('migrate_wizard.settings');
    $this->entityFieldManager = $entity_field_manager;
    $this->entityTypeManager = $entity_type_manager;
    $this->destinyType = isset($this->currentConfig["destiny_type"]) ? $this->currentConfig["destiny_type"] : '';
    $this->manageFormService = $manage_form_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('migrate_wizard.migrate_wizard_manage_data_service'),
      $container->get('migrate_wizard.migrate_wizard_config_builder_service'),
      $container->get('entity_field.manager'),
      $container->get('entity_type.manager'),
      $container->get('migrate_wizard.migrate_wizard_manage_form_service'),
      $container->get('config.typed'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $origin_entity = NULL) {

    $form['origin_bundle'] = [
      '#type' => 'hidden',
      '#value' => $origin_entity->id_origin,
    ];
    if($this->originType != 'user' && $this->originType != 'field_collection_item' && $this->originType != 'paragraphs_item'){
      $this->destinyType = '';
      if ($this->currentConfig && isset($this->currentConfig['destiny_type'])) {
        $this->destinyType = $this->currentConfig['destiny_type'];
      }
    }
    $form['destiny_type'] = [
      '#type' => 'hidden',
      '#value' => $this->destinyType,
      '#prefix' => '<div class="destiny_type_box">',
      '#suffix' => '</div>',
    ];

    $this->manageFormService->buildCheckboxes($form, $this->checkboxes);
    if($this->currentConfig == NULL || $this->destinyType != 'user'){
      $this->manageFormService->buildLangcodes($form, $this->langCodes, $this->i18nMode);
    }

    $options_source_origin_type_node = $this->manageFormService->getOriginNodeTypes();
    $options_source_origin_type_vocabulary = $this->manageFormService->getOriginVocavularyTypes();
    $both_options_source = ['none' => 'Select dependency'] + ['Content types' => $options_source_origin_type_node, 'Vocabularies' => $options_source_origin_type_vocabulary];

    $current_source_type_value = 'none';
    $current_source_type_vocabulary_value = 'none';
    $current_source_type_paragraph_value = 'none';

    $form_state->disableCache(); // @todo investigate this, build ajaxcallback on service get error without this line
    if($this->destinyType != 'user' && $this->originType != 'field_collection_item' && $this->originType != 'paragraphs_item' && $this->originType != 'media'){
      $this->manageFormService->buildSourceTypesForm($form, $current_source_type_value, $current_source_type_vocabulary_value, $current_source_type_paragraph_value);
    }elseif($this->originType != 'field_collection_item' && $this->originType != 'paragraphs_item' && $this->originType != 'media'){
      $form['source_type'] = [
        '#type' => 'hidden',
        '#value' => 'user',
      ];
    }elseif($this->originType == 'field_collection_item' || $this->originType == 'paragraphs_item'){
      $this->manageFormService->buildSourceTypesParagraphsForm($form, $current_source_type_value);
    }elseif($this->originType == 'media'){
      $this->manageFormService->buildSourceTypesMediasForm($form, $current_source_type_value);
    }
    if($this->originType != 'field_collection_item'){
      $default_value = '';
      if (is_array($this->currentConfig) && isset($this->currentConfig['import_only_ids'])) {
        $default_value = $this->currentConfig['import_only_ids'];
      }
      $form['import_only_ids'] = [
        '#type' => 'textfield',
        '#title' => t('import only this ids'),
        '#description' => t('write here the origin ids to import, separated by comma'),
        '#pattern' => '\d+(,\d+)*',
        '#size' => '20',
        '#default_value' => $default_value,
      ];

      $default_value = '';
      if (is_array($this->currentConfig) && isset($this->currentConfig['limit_import'])) {
        $default_value = $this->currentConfig['limit_import'];
      }
      $form['limit_import'] = [
        '#type' => 'number',
        '#title' => t('limit import'),
        '#description' => t('write here the limit of items to import'),
        '#size' => '20',
        '#default_value' => $default_value,
      ];
    }
    if($this->originType != 'media'){
      $form['source_destiny_fields'] = [
        '#type' => 'fieldset',
        '#title' => t('Fields'),
        '#collapsible' => FALSE,
        '#collapsed' => FALSE,
        '#prefix' => '<div class="source-destiny-fields-wrapper" id="source-destiny-fields-wrapper">',
        '#suffix' => '</div>',
      ];
    }
    $current_config_node = [];
    if (is_array($this->currentConfig)) {
      $current_config_node = reset($this->currentConfig);
    }
    $generic_current_source_type_value = $current_source_type_value != 'none' ? $current_source_type_value : $current_source_type_vocabulary_value;

    $current_options_source_destiny_fields_array['fields_array'] = ['none' => 'Select a field'];
    $current_options_source_destiny_fields_array['fields_array_destiny_type'] = [];

    $this->destinyType != 'user' ?: $generic_current_source_type_value = $this->destinyType;
    if($this->destinyType != NULL && $generic_current_source_type_value != 'none'){
      $current_options_source_destiny_fields_array = $this->manageFormService->getDestinyFieldsByBundle($this->destinyType, $generic_current_source_type_value);
    }
    if($this->originType != 'field_collection_item'){
      $this->manageFormService->buildWorkbenchAccessForm($form, $current_options_source_destiny_fields_array, $current_config_node, $both_options_source);
    }
    $form['source_destiny_fields_type'] = [
      '#type' => 'fieldset',
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
      '#attributes' => ['style' => 'display: none;'],
      '#prefix' => '<div class="source-destiny-fields-type-wrapper" id="source-destiny-fields-type-wrapper">',
      '#suffix' => '</div>',
    ];

    foreach ($current_options_source_destiny_fields_array['fields_array_destiny_type'] as $key => $current_options_source_destiny_field_type) {
      $form['source_destiny_fields_type'][$key . '_type'] = [
        '#type' => 'hidden',
        '#name' => $key . '_type',
        '#value' => $current_options_source_destiny_field_type,
      ];
    }

    $this->manageFormService->buildFieldsForm($form, $current_options_source_destiny_fields_array['fields_array'], $generic_current_source_type_value, $both_options_source, $current_config_node, $this->fieldsOriginBundle);

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];
    $form['#attached']['library'][] = 'migrate_wizard/form';
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {}

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void
  {
    $this->manageFormService->submitForm($form, $form_state);
  }

  public function getTitle($type = null): \Drupal\Core\StringTranslation\TranslatableMarkup
  {
    $current_path = $this->manageFormService->pathCurrent->getPath();
    $path = explode('/', $current_path);
    $path = end($path);
    return $this->t('Manage fields '.$this->mwManageDataService->getOriginBundleTitle($path, $type));
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['migrate_wizard.settings'];
  }
}

==> migrate_wizard-2.0.9-alpha1.tar.gz: migrate_wizard/src/Form/BaseFormFields.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\migrate_wizard\MWConfigBuilder;
use Drupal\migrate_wizard\MWManageDataService;
use Drupal\migrate_wizard\MWManageFormService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * @property array|mixed|null currentConfig
 * @property string[] checkboxes
 * @property mixed|string destinyType
 * @property MWManageFormService manageFormService
 * @property array fieldsOriginBundle
 * @property MWManageDataService mwManageDataService
 * @property  array arrayFieldsOriginBundle
 * @property  array entityFieldsDestiny*
 * @property array[]|mixed $langCodes
 * @property $i18nMode
 */
abstract class BaseFormFields extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected $arrayFieldsOriginBundle;

  protected $checkboxes = [
    'build_migration_config' => 'Build migration config',
  ];

  /**
   * {@inheritdoc}
   */
  protected $config;

  protected $currentConfig;

  /**
   * {@inheritdoc}
   */
  protected $destinyType;

  /**
   * {@inheritdoc}
   */
  protected $entityFieldManager;

  /**
   * {@inheritdoc}
   */
  protected $entityFieldsDestiny;

  /**
   * {@inheritdoc}
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  protected $fieldsOriginBundle;

  protected $i18nMode;

  protected $langCodes = [
    'default_lang' => ['markup' => 'Default translation', 'value' => ''],
  ];

  protected $manageFormService;

  /**
   * {@inheritdoc}
   */
  protected $mwConfigBuilder;

  /**
   * {@inheritdoc}
   */
  protected $mwManageDataService;

  protected $originBundle;

  protected $originType;

  /**
   * Constructs a \Drupal\system\ConfigFormBase object.
   *
   * @param ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param TypedConfigManagerInterface|null $typedConfigManager
   *   The typed config manager.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    MWManageDataService $mw_manage_data_service,
    MWConfigBuilder $mw_config_builder,
    EntityFieldManagerInterface $entity_field_manager,
    EntityTypeManagerInterface $entity_type_manager,
    MWManageFormService $manage_form_service,
    protected $typedConfigManager = NULL
  ) {
    parent::__construct($config_factory, $typedConfigManager);
    $this->mwManageDataService = $mw_manage_data_service;
    $this->mwConfigBuilder = $mw_config_builder;
    $this->config = $config_factory->getEditable('migrate_wizard.settings');
    $this->entityFieldManager = $entity_field_manager;
    $this->entityTypeManager = $entity_type_manager;
    $this->destinyType = isset($this->currentConfig['destiny_type']) ? $this->currentConfig['destiny_type'] : '';
    $this->manageFormService = $manage_form_service;
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $origin_entity = NULL) {
    $form['origin_bundle'] = [
      '#type' => 'hidden',
      '#value' => $origin_entity->id_origin,
    ];

    if ($this->originType !== 'user' && $this->originType !== 'field_collection_item' && $this->originType !== 'paragraphs_item') {
      $this->destinyType = '';

      if ($this->currentConfig && isset($this->currentConfig['destiny_type'])) {
        $this->destinyType = $this->currentConfig['destiny_type'];
      }
    }
    $form['destiny_type'] = [
      '#type' => 'hidden',
      '#value' => $this->destinyType,
      '#prefix' => '<div class="destiny_type_box">',
      '#suffix' => '</div>',
    ];

    $this->manageFormService->buildCheckboxes($form, $this->checkboxes);

    if ($this->currentConfig === NULL || $this->destinyType !== 'user') {
      $this->manageFormService->buildLangcodes($form, $this->langCodes, $this->i18nMode);
    }

    $options_source_origin_type_node = $this->manageFormService->getOriginNodeTypes();
    $options_source_origin_type_vocabulary = $this->manageFormService->getOriginVocavularyTypes();
    $both_options_source = ['none' => 'Select dependency'] + ['Content types' => $options_source_origin_type_node, 'Vocabularies' => $options_source_origin_type_vocabulary];

    $current_source_type_value = 'none';
    $current_source_type_vocabulary_value = 'none';
    $current_source_type_paragraph_value = 'none';

    // @todo investigate this, build ajaxcallback on service get error without this line
    $form_state->disableCache();

    if ($this->destinyType !== 'user' && $this->originType !== 'field_collection_item' && $this->originType !== 'paragraphs_item' && $this->originType !== 'media') {
      $this->manageFormService->buildSourceTypesForm($form, $current_source_type_value, $current_source_type_vocabulary_value, $current_source_type_paragraph_value);
    }
    elseif ($this->originType !== 'field_collection_item' && $this->originType !== 'paragraphs_item' && $this->originType !== 'media') {
      $form['source_type'] = [
        '#type' => 'hidden',
        '#value' => 'user',
      ];
    }
    elseif ($this->originType === 'field_collection_item' || $this->originType === 'paragraphs_item') {
      $this->manageFormService->buildSourceTypesParagraphsForm($form, $current_source_type_value);
    }
    elseif ($this->originType === 'media') {
      $this->manageFormService->buildSourceTypesMediasForm($form, $current_source_type_value);
    }

    if ($this->originType !== 'field_collection_item') {
      $default_value = '';

      if (\is_array($this->currentConfig) && isset($this->currentConfig['import_only_ids'])) {
        $default_value = $this->currentConfig['import_only_ids'];
      }
      $form['import_only_ids'] = [
        '#type' => 'textfield',
        '#title' => $this->t('import only this ids'),
        '#description' => $this->t('write here the origin ids to import, separated by comma'),
        '#pattern' => '\d+(,\d+)*',
        '#size' => '20',
        '#default_value' => $default_value,
      ];

      $default_value = '';

      if (\is_array($this->currentConfig) && isset($this->currentConfig['limit_import'])) {
        $default_value = $this->currentConfig['limit_import'];
      }
      $form['limit_import'] = [
        '#type' => 'number',
        '#title' => $this->t('limit import'),
        '#description' => $this->t('write here the limit of items to import'),
        '#size' => '20',
        '#default_value' => $default_value,
      ];
    }

    if ($this->originType !== 'media') {
      $form['source_destiny_fields'] = [
        '#type' => 'fieldset',
        '#title' => $this->t('Fields'),
        '#collapsible' => FALSE,
        '#collapsed' => FALSE,
        '#prefix' => '<div class="source-destiny-fields-wrapper" id="source-destiny-fields-wrapper">',
        '#suffix' => '</div>',
      ];
    }
    $current_config_node = [];

    if (\is_array($this->currentConfig)) {
      $current_config_node = reset($this->currentConfig);
    }
    $generic_current_source_type_value = $current_source_type_value !== 'none' ? $current_source_type_value : $current_source_type_vocabulary_value;

    $current_options_source_destiny_fields_array['fields_array'] = ['none' => 'Select a field'];
    $current_options_source_destiny_fields_array['fields_array_destiny_type'] = [];

    $this->destinyType !== 'user' ?: $generic_current_source_type_value = $this->destinyType;

    if ($this->destinyType !== NULL && $generic_current_source_type_value !== 'none') {
      $current_options_source_destiny_fields_array = $this->manageFormService->getDestinyFieldsByBundle($this->destinyType, $generic_current_source_type_value);
    }

    if ($this->originType !== 'field_collection_item') {
      $this->manageFormService->buildWorkbenchAccessForm($form, $current_options_source_destiny_fields_array, $current_config_node, $both_options_source);
    }
    $form['source_destiny_fields_type'] = [
      '#type' => 'fieldset',
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
      '#attributes' => ['style' => 'display: none;'],
      '#prefix' => '<div class="source-destiny-fields-type-wrapper" id="source-destiny-fields-type-wrapper">',
      '#suffix' => '</div>',
    ];

    foreach ($current_options_source_destiny_fields_array['fields_array_destiny_type'] as $key => $current_options_source_destiny_field_type) {
      $form['source_destiny_fields_type'][$key . '_type'] = [
        '#type' => 'hidden',
        '#name' => $key . '_type',
        '#value' => $current_options_source_destiny_field_type,
      ];
    }

    $this->manageFormService->buildFieldsForm($form, $current_options_source_destiny_fields_array['fields_array'], $generic_current_source_type_value, $both_options_source, $current_config_node, $this->fieldsOriginBundle);

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];
    $form['#attached']['library'][] = 'migrate_wizard/form';

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('migrate_wizard.migrate_wizard_manage_data_service'),
      $container->get('migrate_wizard.migrate_wizard_config_builder_service'),
      $container->get('entity_field.manager'),
      $container->get('entity_type.manager'),
      $container->get('migrate_wizard.migrate_wizard_manage_form_service'),
      $container->get('config.typed'),
    );
  }

  public function getTitle($type = NULL): \Drupal\Core\StringTranslation\TranslatableMarkup {
    $current_path = $this->manageFormService->pathCurrent->getPath();
    $path = explode('/', $current_path);
    $path = end($path);

    return $this->t('Manage fields ' . $this->mwManageDataService->getOriginBundleTitle($path, $type));
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->manageFormService->submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {}

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['migrate_wizard.settings'];
  }

}
